# u-calc: A calculator with uncertainties

Tired of doing physics calculations by hand or with spreadsheets? Look no further, because ths python module is there to make these calculations as easy as ever!